@@ -4,13 +4,18 @@ import six
 
 '''
 Adds the ability to send date and datetime objects to the API
+Datetime objects will be encoded/ decoded with microseconds
 The date and datetime formats from the API are automatically supported and parsed
 '''
+DATETIME_FORMAT = "%Y-%m-%dT%H:%M:%S.%f"
+DATE_FORMAT = "%Y-%m-%d"
 
 
 def _datetime_encoder(obj):
-    if isinstance(obj, (datetime.datetime, datetime.date)):
-        return obj.isoformat()
+    if isinstance(obj, datetime.datetime):
+        return datetime.datetime.strftime(obj, DATETIME_FORMAT)
+    if isinstance(obj, datetime.date):
+        return datetime.datetime.strftime(obj, DATE_FORMAT)
 
 
 def _datetime_decoder(dict_):
@@ -26,15 +31,13 @@ def _datetime_decoder(dict_):
             try:
                 # The api always returns times like this
                 # 2014-07-25T09:12:24.735
-                datetime_obj = datetime.datetime.strptime(
-                    value, "%Y-%m-%dT%H:%M:%S.%f")
+                datetime_obj = datetime.datetime.strptime(value, DATETIME_FORMAT)
                 dict_[key] = datetime_obj
             except (ValueError, TypeError):
                 try:
                     # The api always returns times like this
                     # 2014-07-25T09:12:24.735
-                    datetime_obj = datetime.datetime.strptime(
-                        value, "%Y-%m-%d")
+                    datetime_obj = datetime.datetime.strptime(value, DATE_FORMAT)
                     dict_[key] = datetime_obj.date()
                 except (ValueError, TypeError):
                     continue
